/*
 */

#ifndef SDCCCONF_HEADER
#define SDCCCONF_HEADER


#undef SDCC_VERSION_HI
#undef SDCC_VERSION_LO
#undef SDCC_VERSION_P
#undef SDCC_VERSION_STR

#undef DIR_SEPARATOR_STRING
#undef DIR_SEPARATOR_CHAR

#undef PREFIX
#undef EXEC_PREFIX
#undef BINDIR
#undef DATADIR

#undef INCLUDE_DIR_SUFFIX
#undef LIB_DIR_SUFFIX

#undef BIN2DATA_DIR
#undef PREFIX2BIN_DIR
#undef PREFIX2DATA_DIR

/* environment variables */
#undef SDCC_DIR_NAME
#undef SDCC_INCLUDE_NAME
#undef SDCC_LIB_NAME

/* standard libraries */
#undef STD_LIB
#undef STD_INT_LIB
#undef STD_LONG_LIB
#undef STD_FP_LIB
#undef STD_DS390_LIB
#undef STD_DS400_LIB
#undef STD_XA51_LIB

#undef HAVE_SYS_SOCKET_H

#undef HAVE_STRERROR
#undef HAVE_VSNPRINTF
#undef HAVE_SNPRINTF
#undef HAVE_VSPRINTF
#undef HAVE_MKSTEMP

#undef RETSIGTYPE

#undef TYPE_BYTE
#undef TYPE_WORD
#undef TYPE_DWORD
#undef TYPE_UBYTE
#undef TYPE_UWORD
#undef TYPE_UDWORD

#undef WORDS_BIGENDIAN

#undef OPT_DISABLE_MCS51
#undef OPT_DISABLE_GBZ80
#undef OPT_DISABLE_Z80
#undef OPT_DISABLE_AVR
#undef OPT_DISABLE_DS390
#undef OPT_DISABLE_DS400
#undef OPT_DISABLE_TININative
#undef OPT_DISABLE_PIC
#undef OPT_DISABLE_PIC16
#undef OPT_DISABLE_XA51
#undef OPT_DISABLE_HC08

#undef OPT_ENABLE_LIBGC

#endif

/* End of config.h */
